devicesinlan_gui - Turulomio

# NAME

devicesinlan_gui: Busca todos los dispositivos de tu LAN. Después, puedes establecer alias a tus dispositivos conocidos para detectar dispositivos extraños en tu red.

# SYNOPSIS

devicesinlan_gui [--help] [--version] [--debug DEBUG]

# DESCRIPCIÓN

En el menú de la aplicación tienes las siguientes funcionalidades:

Dispositivo > Nuevo escaneado

Busca todos los dispositivos en la LAN y los muestra en una nueva pestaña. Si algún dispositivo no está en la lista de dispositivos conocidos, se mostrará con un fondo rojo. Los dispositivos con fondo verde son dispositivos de confianza

Dispositivos > Muestra la base de datos de dispositivos

Muestra todo los dispositivos conocidos en una nueva pestaña.

Hacer click derecho te permite editar la base de datos de dispositivos conocidos.

Dispositivos > Carga una lista de dispositivos

Carga una lista de dispositivos conocidos en formato xml.

Dispositivos > Grabar lista de dispositivos

Graba la lista de dispositivos conocidos a un fichero xml.

Dispositivos > Borrar la base de datos

Borra todos los dispositivos conocidos.

Esta opción borra todos los dispositivos conocidos de la base de datos.

Configuración > Preferencias

En esta ventana puedes seleccionar tu idioma preferido y puedes configurar el número de peticicones concurrentes.

Ayuda > Ayuda

Muestra esta información de ayuda.

Ayuda > Acerca de

Muestra información sobre la licencia y los autores de DevicesInLAN.

Ayuda > Busca actualizaciones

Busca actualizaciones en el repositorio de DevicesInLan.

Ayuda > Salir

Sale del programa.

Created with libmangenerator at 2025-12-28